@@ -39,7 +39,7 @@ class Command(ABC, metaclass=CommandMeta):
         self = super().__new__(cls)
         self.__ctx = ctx
         if not hasattr(self, 'ctx'):
-            self.ctx = ctx
+            self.ctx: Context = ctx  # noqa  # PyCharm complains this is invalid, but doesn't understand it without it
         return self
 
     def __repr__(self) -> str:
@@ -112,11 +112,9 @@ class Command(ABC, metaclass=CommandMeta):
         cmd_cls = cls
         with ExitStack() as stack:
             stack.enter_context(ctx)
-            sub_cmd = CommandParser.parse_args_and_get_next_cmd(ctx)
-            while sub_cmd:
+            while sub_cmd := CommandParser.parse_args_and_get_next_cmd(ctx):
                 cmd_cls = sub_cmd
                 ctx = stack.enter_context(ctx._sub_context(cmd_cls))
-                sub_cmd = CommandParser.parse_args_and_get_next_cmd(ctx)
 
             return cmd_cls()
 
@@ -127,7 +125,7 @@ class Command(ABC, metaclass=CommandMeta):
         Primary entry point for running a command.  Subclasses generally should not override this method.
 
         Handles exceptions using the configured :class:`.ErrorHandler`.  Alternate error handlers can be specified
-        via the :paramref:`~.core.CommandMeta.__new__.error_handler` parameter during Command class initialization.
+        via the :paramref:`~.core.CommandMeta.error_handler` parameter during Command class initialization.
         To skip error handling, define the class with ``error_handler=None``.
 
         Calls the following methods in order:
@@ -163,19 +161,18 @@ class Command(ABC, metaclass=CommandMeta):
         The first method called by :meth:`.__call__` (before :meth:`.main` and others).
 
         Validates the number of ActionFlags that were specified, and calls all of the specified
-        :obj:`~.parameters.before_main` / :obj:`~.parameters.action_flag` actions such as ``--help`` that were
+        :func:`~.options.before_main` / :obj:`~.options.action_flag` actions such as ``--help`` that were
         defined with ``before_main=True`` and ``always_available=True`` in their configured order.
 
-        :param args: Positional arguments to pass to the :obj:`~.parameters.action_flag` methods
-        :param kwargs: Keyword arguments to pass to the :obj:`~.parameters.action_flag` methods
+        :param args: Positional arguments to pass to the :obj:`~.options.action_flag` methods
+        :param kwargs: Keyword arguments to pass to the :obj:`~.options.action_flag` methods
         """
         ctx = self.__ctx
         n_flags = ctx.action_flag_count
         if n_flags and not ctx.config.multiple_action_flags and n_flags > 1:
             raise ParamConflict(ctx.all_action_flags, 'combining multiple action flags is disabled')
 
-        before = ctx.categorized_action_flags[ActionPhase.BEFORE_MAIN]
-        if before:
+        if before := ctx.categorized_action_flags[ActionPhase.BEFORE_MAIN]:
             action = get_params(self).action
             if action is not None and not ctx.config.action_after_action_flags:
                 raise ParamConflict([action, *before], 'combining an action with action flags is disabled')
@@ -204,11 +201,11 @@ class Command(ABC, metaclass=CommandMeta):
         """
         Called by :meth:`.__call__` after :meth:`._init_command_` and before :meth:`.main` is called.
 
-        Calls all of the specified :obj:`~.parameters.before_main` / :obj:`~.parameters.action_flag` actions that were
-        defined with ``before_main=True`` and ``always_available=False`` in their configured order.
+        Calls all of the specified :func:`~.options.before_main` / :obj:`~.options.action_flag` actions that
+        were defined with ``before_main=True`` and ``always_available=False`` in their configured order.
 
-        :param args: Positional arguments to pass to the :obj:`~.parameters.action_flag` methods
-        :param kwargs: Keyword arguments to pass to the :obj:`~.parameters.action_flag` methods
+        :param args: Positional arguments to pass to the :obj:`~.options.action_flag` methods
+        :param kwargs: Keyword arguments to pass to the :obj:`~.options.action_flag` methods
         """
         for param in self.__ctx.iter_action_flags(ActionPhase.BEFORE_MAIN):
             param.func(self, *args, **kwargs)
@@ -218,9 +215,9 @@ class Command(ABC, metaclass=CommandMeta):
         Primary method that is called when running a Command.
 
         If any arguments were specified that are associated with triggering a method that was decorated / registered as
-        a positional :class:`~.parameters.Action`'s target method, then that method is called here.
+        a positional :class:`~.choice_map.Action`'s target method, then that method is called here.
 
-        Commands that do not have any positional :class:`Actions<.parameters.Action>` can override this method, and do
+        Commands that do not have any positional :class:`Actions<.choice_map.Action>` can override this method, and do
         **not** need to call ``super().main(*args, **kwargs)``.
 
         Initialization code that is common for all actions, or that should be run before :meth:`._before_main_` should
@@ -241,11 +238,11 @@ class Command(ABC, metaclass=CommandMeta):
     def _after_main_(self, *args, **kwargs):
         """
         Called by :meth:`.__call__` after :meth:`.main` is called.  Calls all of the specified
-        :obj:`~.parameters.after_main` / :obj:`~.parameters.action_flag` actions that were defined with
+        :func:`~.options.after_main` / :obj:`~.options.action_flag` actions that were defined with
         ``before_main=False`` in their configured order.
 
-        :param args: Positional arguments to pass to the :obj:`~.parameters.action_flag` methods
-        :param kwargs: Keyword arguments to pass to the :obj:`~.parameters.action_flag` methods
+        :param args: Positional arguments to pass to the :obj:`~.options.action_flag` methods
+        :param kwargs: Keyword arguments to pass to the :obj:`~.options.action_flag` methods
         """
         for param in self.__ctx.iter_action_flags(ActionPhase.AFTER_MAIN):
             param.func(self, *args, **kwargs)
